#[non_exhaustive]pub enum CreateCheckoutSessionConsentCollectionPromotions {
Auto,
None,
Unknown(String),
}Expand description
If set to auto, enables the collection of customer consent for promotional communications.
The Checkout.
Session will determine whether to display an option to opt into promotional communication
from the merchant depending on the customer’s locale.
Only available to US merchants and US customers.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Auto
None
Unknown(String)
An unrecognized value from Stripe. Should not be used as a request parameter.
Implementations