#[non_exhaustive]pub enum CreateCheckoutSessionConsentCollectionTermsOfService {
None,
Required,
Unknown(String),
}Expand description
If set to required, it requires customers to check a terms of service checkbox before being able to pay.
There must be a valid terms of service URL set in your Dashboard settings.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
None
Required
Unknown(String)
An unrecognized value from Stripe. Should not be used as a request parameter.
Implementations