#[non_exhaustive]pub enum CreateCheckoutSessionCustomerUpdateAddress {
Auto,
Never,
Unknown(String),
}Expand description
Describes whether Checkout saves the billing address onto customer.address.
To always collect a full billing address, use billing_address_collection. Defaults to never.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Auto
Never
Unknown(String)
An unrecognized value from Stripe. Should not be used as a request parameter.
Implementations