#[non_exhaustive]pub enum CreateCheckoutSessionExcludedPaymentMethodTypes {
Show 54 variants
AcssDebit,
Affirm,
AfterpayClearpay,
Alipay,
Alma,
AmazonPay,
AuBecsDebit,
BacsDebit,
Bancontact,
Billie,
Bizum,
Blik,
Boleto,
Card,
Cashapp,
Crypto,
CustomerBalance,
Eps,
Fpx,
Giropay,
Grabpay,
Ideal,
KakaoPay,
Klarna,
Konbini,
KrCard,
MbWay,
Mobilepay,
Multibanco,
NaverPay,
NzBankAccount,
Oxxo,
P24,
PayByBank,
Payco,
Paynow,
Paypal,
Payto,
Pix,
Promptpay,
RevolutPay,
SamsungPay,
Satispay,
Scalapay,
SepaDebit,
Sofort,
Sunbit,
Swish,
Twint,
Upi,
UsBankAccount,
WechatPay,
Zip,
Unknown(String),
}Expand description
A list of the types of payment methods (e.g., card) that should be excluded from this Checkout Session.
This should only be used when payment methods for this Checkout Session are managed through the Stripe Dashboard.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AcssDebit
Affirm
AfterpayClearpay
Alipay
Alma
AmazonPay
AuBecsDebit
BacsDebit
Bancontact
Billie
Bizum
Blik
Boleto
Card
Cashapp
Crypto
CustomerBalance
Eps
Fpx
Giropay
Grabpay
Ideal
KakaoPay
Klarna
Konbini
KrCard
MbWay
Mobilepay
Multibanco
NzBankAccount
Oxxo
P24
PayByBank
Payco
Paynow
Paypal
Payto
Pix
Promptpay
RevolutPay
SamsungPay
Satispay
Scalapay
SepaDebit
Sofort
Sunbit
Swish
Twint
Upi
UsBankAccount
WechatPay
Zip
Unknown(String)
An unrecognized value from Stripe. Should not be used as a request parameter.
Implementations