#[non_exhaustive]pub enum CreateCheckoutSessionPaymentMethodDataAllowRedisplay {
Always,
Limited,
Unspecified,
Unknown(String),
}Expand description
Allow redisplay will be set on the payment method on confirmation and indicates whether this payment method can be shown again to the customer in a checkout flow. Only set this field if you wish to override the allow_redisplay value determined by Checkout.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Always
Limited
Unspecified
Unknown(String)
An unrecognized value from Stripe. Should not be used as a request parameter.
Implementations