#[non_exhaustive]pub enum CreateCheckoutSessionPaymentMethodOptionsCardRequestThreeDSecure {
Any,
Automatic,
Challenge,
Unknown(String),
}Expand description
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and other requirements.
However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option.
If not provided, this value defaults to automatic.
Read our guide on manually requesting 3D Secure for more information on how this configuration interacts with Radar and our SCA Engine.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Any
Automatic
Challenge
Unknown(String)
An unrecognized value from Stripe. Should not be used as a request parameter.
Implementations