Enum CreateCheckoutSessionPaymentMethodOptionsCustomerBalanceBankTransferRequestedAddressTypes
#[non_exhaustive]pub enum CreateCheckoutSessionPaymentMethodOptionsCustomerBalanceBankTransferRequestedAddressTypes {
Aba,
Iban,
Sepa,
SortCode,
Spei,
Swift,
Zengin,
Unknown(String),
}Expand description
List of address types that should be returned in the financial_addresses response. If not specified, all valid types will be returned.
Permitted values include: sort_code, zengin, iban, or spei.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Aba
Iban
Sepa
SortCode
Spei
Swift
Zengin
Unknown(String)
An unrecognized value from Stripe. Should not be used as a request parameter.
Implementations