#[non_exhaustive]pub enum CreateCheckoutSessionSubscriptionDataBillingModeType {
Classic,
Flexible,
Unknown(String),
}Expand description
Controls the calculation and orchestration of prorations and invoices for subscriptions.
If no value is passed, the default is flexible.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Classic
Flexible
Unknown(String)
An unrecognized value from Stripe. Should not be used as a request parameter.
Implementations