#[non_exhaustive]pub enum CreateCheckoutSessionWalletOptionsLinkDisplay {
Auto,
Never,
Unknown(String),
}Expand description
Specifies whether Checkout should display Link as a payment option.
By default, Checkout will display all the supported wallets that the Checkout Session was created with.
This is the auto behavior, and it is the default choice.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Auto
Never
Unknown(String)
An unrecognized value from Stripe. Should not be used as a request parameter.
Implementations