pub struct CreateCheckoutSessionAutomaticTax {
pub enabled: bool,
pub liability: Option<CreateCheckoutSessionAutomaticTaxLiability>,
}Expand description
Settings for automatic tax lookup for this session and resulting payments, invoices, and subscriptions.
Fields
enabled: boolSet to true to calculate tax automatically using the customer’s location.
Enabling this parameter causes Checkout to collect any billing address information necessary for tax calculation.
liability: Option<CreateCheckoutSessionAutomaticTaxLiability>The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.
Implementations