pub struct CreateCheckoutSessionConsentCollection {
pub payment_method_reuse_agreement: Option<CreateCheckoutSessionConsentCollectionPaymentMethodReuseAgreement>,
pub promotions: Option<CreateCheckoutSessionConsentCollectionPromotions>,
pub terms_of_service: Option<CreateCheckoutSessionConsentCollectionTermsOfService>,
}Expand description
Configure fields for the Checkout Session to gather active consent from customers.
Fields
payment_method_reuse_agreement: Option<CreateCheckoutSessionConsentCollectionPaymentMethodReuseAgreement>Determines the display of payment method reuse agreement text in the UI.
If set to hidden, it will hide legal text related to the reuse of a payment method.
promotions: Option<CreateCheckoutSessionConsentCollectionPromotions>If set to auto, enables the collection of customer consent for promotional communications.
The Checkout.
Session will determine whether to display an option to opt into promotional communication
from the merchant depending on the customer’s locale.
Only available to US merchants and US customers.
terms_of_service: Option<CreateCheckoutSessionConsentCollectionTermsOfService>If set to required, it requires customers to check a terms of service checkbox before being able to pay.
There must be a valid terms of service URL set in your Dashboard settings.
Implementations