pub struct CreateCheckoutSessionConsentCollectionPaymentMethodReuseAgreement {
pub position: CreateCheckoutSessionConsentCollectionPaymentMethodReuseAgreementPosition,
}Expand description
Determines the display of payment method reuse agreement text in the UI.
If set to hidden, it will hide legal text related to the reuse of a payment method.
Fields
position: CreateCheckoutSessionConsentCollectionPaymentMethodReuseAgreementPositionDetermines the position and visibility of the payment method reuse agreement in the UI.
When set to auto, Stripe’s.
defaults will be used.
When set to hidden, the payment method reuse agreement text will always be hidden in the UI.
Implementations
Sourceimpl CreateCheckoutSessionConsentCollectionPaymentMethodReuseAgreement
impl CreateCheckoutSessionConsentCollectionPaymentMethodReuseAgreement
pub fn new( position: impl Into<CreateCheckoutSessionConsentCollectionPaymentMethodReuseAgreementPosition>, ) -> Self