pub struct CreateCheckoutSessionCustomFieldsDropdownOptions {
pub label: String,
pub value: String,
}Expand description
The options available for the customer to select. Up to 200 options allowed.
Fields
label: StringThe label for the option, displayed to the customer. Up to 100 characters.
value: StringThe value for this option, not displayed to the customer, used by your integration to reconcile the option selected by the customer. Must be unique to this option, alphanumeric, and up to 100 characters.
Implementations