pub struct CreateCheckoutSessionCustomText {
pub after_submit: Option<CustomTextPositionParam>,
pub shipping_address: Option<CustomTextPositionParam>,
pub submit: Option<CustomTextPositionParam>,
pub terms_of_service_acceptance: Option<CustomTextPositionParam>,
}Expand description
Display additional text for your customers using custom text.
You can’t set this parameter if ui_mode is custom.
Fields
after_submit: Option<CustomTextPositionParam>Custom text that should be displayed after the payment confirmation button.
shipping_address: Option<CustomTextPositionParam>Custom text that should be displayed alongside shipping address collection.
submit: Option<CustomTextPositionParam>Custom text that should be displayed alongside the payment confirmation button.
terms_of_service_acceptance: Option<CustomTextPositionParam>Custom text that should be displayed in place of the default terms of service agreement text.
Implementations