pub struct CreateCheckoutSessionCustomerUpdate {
pub address: Option<CreateCheckoutSessionCustomerUpdateAddress>,
pub name: Option<CreateCheckoutSessionCustomerUpdateName>,
pub shipping: Option<CreateCheckoutSessionCustomerUpdateShipping>,
}Expand description
Controls what fields on Customer can be updated by the Checkout Session.
Can only be provided when customer is provided.
Fields
address: Option<CreateCheckoutSessionCustomerUpdateAddress>Describes whether Checkout saves the billing address onto customer.address.
To always collect a full billing address, use billing_address_collection. Defaults to never.
name: Option<CreateCheckoutSessionCustomerUpdateName>Describes whether Checkout saves the name onto customer.name. Defaults to never.
shipping: Option<CreateCheckoutSessionCustomerUpdateShipping>Describes whether Checkout saves shipping information onto customer.shipping.
To collect shipping information, use shipping_address_collection. Defaults to never.
Implementations