pub struct CreateCheckoutSessionInvoiceCreationInvoiceDataRenderingOptions {
pub amount_tax_display: Option<CreateCheckoutSessionInvoiceCreationInvoiceDataRenderingOptionsAmountTaxDisplay>,
pub template: Option<String>,
}Expand description
Default options for invoice PDF rendering for this customer.
Fields
amount_tax_display: Option<CreateCheckoutSessionInvoiceCreationInvoiceDataRenderingOptionsAmountTaxDisplay>How line-item prices and amounts will be displayed with respect to tax on invoice PDFs.
One of exclude_tax or include_inclusive_tax.
include_inclusive_tax will include inclusive tax (and exclude exclusive tax) in invoice PDF amounts.
exclude_tax will exclude all tax (inclusive and exclusive alike) from invoice PDF amounts.
template: Option<String>ID of the invoice rendering template to use for this invoice.
Implementations