pub struct CreateCheckoutSessionLineItems {
pub adjustable_quantity: Option<CreateCheckoutSessionLineItemsAdjustableQuantity>,
pub metadata: Option<HashMap<String, String>>,
pub price: Option<String>,
pub price_data: Option<CreateCheckoutSessionLineItemsPriceData>,
pub quantity: Option<u64>,
pub tax_rates: Option<Vec<String>>,
}Expand description
A list of items the customer is purchasing.
Use this parameter to pass one-time or recurring Prices.
The parameter is required for payment and subscription mode.
For payment mode, there is a maximum of 100 line items, however it is recommended to consolidate line items if there are more than a few dozen.
For subscription mode, there is a maximum of 20 line items with recurring Prices and 20 line items with one-time Prices.
Line items with one-time Prices will be on the initial invoice only.
Fields
adjustable_quantity: Option<CreateCheckoutSessionLineItemsAdjustableQuantity>When set, provides configuration for this item’s quantity to be adjusted by the customer during Checkout.
metadata: Option<HashMap<String, String>>Set of key-value pairs that you can attach to an object.
This can be useful for storing additional information about the object in a structured format.
Individual keys can be unset by posting an empty value to them.
All keys can be unset by posting an empty value to metadata.
price: Option<String>price_data: Option<CreateCheckoutSessionLineItemsPriceData>Data used to generate a new Price object inline.
One of price or price_data is required.
quantity: Option<u64>The quantity of the line item being purchased.
Quantity should not be defined when recurring.usage_type=metered.
tax_rates: Option<Vec<String>>The tax rates which apply to this line item.
Implementations