pub struct CreateCheckoutSessionLineItemsAdjustableQuantity {
pub enabled: bool,
pub maximum: Option<i64>,
pub minimum: Option<i64>,
}Expand description
When set, provides configuration for this item’s quantity to be adjusted by the customer during Checkout.
Fields
enabled: boolSet to true if the quantity can be adjusted to any non-negative integer.
maximum: Option<i64>The maximum quantity the customer can purchase for the Checkout Session. By default this value is 99. You can specify a value up to 999999.
minimum: Option<i64>The minimum quantity the customer must purchase for the Checkout Session. By default this value is 0.
Implementations