pub struct CreateCheckoutSessionNameCollection {
pub business: Option<CreateCheckoutSessionNameCollectionBusiness>,
pub individual: Option<CreateCheckoutSessionNameCollectionIndividual>,
}Expand description
Controls name collection settings for the session.
You can configure Checkout to collect your customers’ business names, individual names, or both. Each name field can be either required or optional.
If a Customer is created or provided, the names can be saved to the Customer object as well.
Fields
business: Option<CreateCheckoutSessionNameCollectionBusiness>Controls settings applied for collecting the customer’s business name on the session.
individual: Option<CreateCheckoutSessionNameCollectionIndividual>Controls settings applied for collecting the customer’s individual name on the session.
Implementations