pub struct CreateCheckoutSessionOptionalItemsAdjustableQuantity {
pub enabled: bool,
pub maximum: Option<i64>,
pub minimum: Option<i64>,
}Expand description
When set, provides configuration for the customer to adjust the quantity of the line item created when a customer chooses to add this optional item to their order.
Fields
enabled: boolSet to true if the quantity can be adjusted to any non-negative integer.
maximum: Option<i64>The maximum quantity of this item the customer can purchase. By default this value is 99. You can specify a value up to 999999.
minimum: Option<i64>The minimum quantity of this item the customer must purchase, if they choose to purchase it.
Because this item is optional, the customer will always be able to remove it from their order, even if the minimum configured here is greater than 0.
By default this value is 0.
Implementations