pub struct CreateCheckoutSessionPaymentIntentDataShipping {
pub address: CreateCheckoutSessionPaymentIntentDataShippingAddress,
pub carrier: Option<String>,
pub name: String,
pub phone: Option<String>,
pub tracking_number: Option<String>,
}Expand description
Shipping information for this payment.
Fields
address: CreateCheckoutSessionPaymentIntentDataShippingAddressShipping address.
carrier: Option<String>The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
name: StringRecipient name.
phone: Option<String>Recipient phone (including extension).
tracking_number: Option<String>The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
Implementations