pub struct CreateCheckoutSessionPaymentMethodData {
pub allow_redisplay: Option<CreateCheckoutSessionPaymentMethodDataAllowRedisplay>,
}Expand description
This parameter allows you to set some attributes on the payment method created during a Checkout session.
Fields
allow_redisplay: Option<CreateCheckoutSessionPaymentMethodDataAllowRedisplay>Allow redisplay will be set on the payment method on confirmation and indicates whether this payment method can be shown again to the customer in a checkout flow. Only set this field if you wish to override the allow_redisplay value determined by Checkout.
Implementations