pub struct CreateCheckoutSessionPaymentMethodOptions {Show 49 fields
pub acss_debit: Option<CreateCheckoutSessionPaymentMethodOptionsAcssDebit>,
pub affirm: Option<CreateCheckoutSessionPaymentMethodOptionsAffirm>,
pub afterpay_clearpay: Option<CreateCheckoutSessionPaymentMethodOptionsAfterpayClearpay>,
pub alipay: Option<CreateCheckoutSessionPaymentMethodOptionsAlipay>,
pub alma: Option<CreateCheckoutSessionPaymentMethodOptionsAlma>,
pub amazon_pay: Option<CreateCheckoutSessionPaymentMethodOptionsAmazonPay>,
pub au_becs_debit: Option<CreateCheckoutSessionPaymentMethodOptionsAuBecsDebit>,
pub bacs_debit: Option<CreateCheckoutSessionPaymentMethodOptionsBacsDebit>,
pub bancontact: Option<CreateCheckoutSessionPaymentMethodOptionsBancontact>,
pub billie: Option<CreateCheckoutSessionPaymentMethodOptionsBillie>,
pub boleto: Option<CreateCheckoutSessionPaymentMethodOptionsBoleto>,
pub card: Option<CreateCheckoutSessionPaymentMethodOptionsCard>,
pub cashapp: Option<CreateCheckoutSessionPaymentMethodOptionsCashapp>,
pub crypto: Option<CreateCheckoutSessionPaymentMethodOptionsCrypto>,
pub customer_balance: Option<CreateCheckoutSessionPaymentMethodOptionsCustomerBalance>,
pub demo_pay: Option<CreateCheckoutSessionPaymentMethodOptionsDemoPay>,
pub eps: Option<CreateCheckoutSessionPaymentMethodOptionsEps>,
pub fpx: Option<CreateCheckoutSessionPaymentMethodOptionsFpx>,
pub giropay: Option<CreateCheckoutSessionPaymentMethodOptionsGiropay>,
pub grabpay: Option<CreateCheckoutSessionPaymentMethodOptionsGrabpay>,
pub ideal: Option<CreateCheckoutSessionPaymentMethodOptionsIdeal>,
pub kakao_pay: Option<CreateCheckoutSessionPaymentMethodOptionsKakaoPay>,
pub klarna: Option<CreateCheckoutSessionPaymentMethodOptionsKlarna>,
pub konbini: Option<CreateCheckoutSessionPaymentMethodOptionsKonbini>,
pub kr_card: Option<CreateCheckoutSessionPaymentMethodOptionsKrCard>,
pub link: Option<CreateCheckoutSessionPaymentMethodOptionsLink>,
pub mobilepay: Option<CreateCheckoutSessionPaymentMethodOptionsMobilepay>,
pub multibanco: Option<CreateCheckoutSessionPaymentMethodOptionsMultibanco>,
pub naver_pay: Option<CreateCheckoutSessionPaymentMethodOptionsNaverPay>,
pub oxxo: Option<CreateCheckoutSessionPaymentMethodOptionsOxxo>,
pub p24: Option<CreateCheckoutSessionPaymentMethodOptionsP24>,
pub pay_by_bank: Option<Value>,
pub payco: Option<CreateCheckoutSessionPaymentMethodOptionsPayco>,
pub paynow: Option<CreateCheckoutSessionPaymentMethodOptionsPaynow>,
pub paypal: Option<CreateCheckoutSessionPaymentMethodOptionsPaypal>,
pub payto: Option<CreateCheckoutSessionPaymentMethodOptionsPayto>,
pub pix: Option<CreateCheckoutSessionPaymentMethodOptionsPix>,
pub revolut_pay: Option<CreateCheckoutSessionPaymentMethodOptionsRevolutPay>,
pub samsung_pay: Option<CreateCheckoutSessionPaymentMethodOptionsSamsungPay>,
pub satispay: Option<CreateCheckoutSessionPaymentMethodOptionsSatispay>,
pub scalapay: Option<CreateCheckoutSessionPaymentMethodOptionsScalapay>,
pub sepa_debit: Option<CreateCheckoutSessionPaymentMethodOptionsSepaDebit>,
pub sofort: Option<CreateCheckoutSessionPaymentMethodOptionsSofort>,
pub sunbit: Option<CreateCheckoutSessionPaymentMethodOptionsSunbit>,
pub swish: Option<CreateCheckoutSessionPaymentMethodOptionsSwish>,
pub twint: Option<CreateCheckoutSessionPaymentMethodOptionsTwint>,
pub upi: Option<CreateCheckoutSessionPaymentMethodOptionsUpi>,
pub us_bank_account: Option<CreateCheckoutSessionPaymentMethodOptionsUsBankAccount>,
pub wechat_pay: Option<CreateCheckoutSessionPaymentMethodOptionsWechatPay>,
}Expand description
Payment-method-specific configuration.
Fields
acss_debit: Option<CreateCheckoutSessionPaymentMethodOptionsAcssDebit>contains details about the ACSS Debit payment method options.
You can’t set this parameter if ui_mode is elements.
affirm: Option<CreateCheckoutSessionPaymentMethodOptionsAffirm>contains details about the Affirm payment method options.
afterpay_clearpay: Option<CreateCheckoutSessionPaymentMethodOptionsAfterpayClearpay>contains details about the Afterpay Clearpay payment method options.
alipay: Option<CreateCheckoutSessionPaymentMethodOptionsAlipay>contains details about the Alipay payment method options.
alma: Option<CreateCheckoutSessionPaymentMethodOptionsAlma>contains details about the Alma payment method options.
amazon_pay: Option<CreateCheckoutSessionPaymentMethodOptionsAmazonPay>contains details about the AmazonPay payment method options.
au_becs_debit: Option<CreateCheckoutSessionPaymentMethodOptionsAuBecsDebit>contains details about the AU Becs Debit payment method options.
bacs_debit: Option<CreateCheckoutSessionPaymentMethodOptionsBacsDebit>contains details about the Bacs Debit payment method options.
bancontact: Option<CreateCheckoutSessionPaymentMethodOptionsBancontact>contains details about the Bancontact payment method options.
billie: Option<CreateCheckoutSessionPaymentMethodOptionsBillie>contains details about the Billie payment method options.
boleto: Option<CreateCheckoutSessionPaymentMethodOptionsBoleto>contains details about the Boleto payment method options.
card: Option<CreateCheckoutSessionPaymentMethodOptionsCard>contains details about the Card payment method options.
cashapp: Option<CreateCheckoutSessionPaymentMethodOptionsCashapp>contains details about the Cashapp Pay payment method options.
crypto: Option<CreateCheckoutSessionPaymentMethodOptionsCrypto>contains details about the Crypto payment method options.
customer_balance: Option<CreateCheckoutSessionPaymentMethodOptionsCustomerBalance>contains details about the Customer Balance payment method options.
demo_pay: Option<CreateCheckoutSessionPaymentMethodOptionsDemoPay>contains details about the DemoPay payment method options.
eps: Option<CreateCheckoutSessionPaymentMethodOptionsEps>contains details about the EPS payment method options.
fpx: Option<CreateCheckoutSessionPaymentMethodOptionsFpx>contains details about the FPX payment method options.
giropay: Option<CreateCheckoutSessionPaymentMethodOptionsGiropay>contains details about the Giropay payment method options.
grabpay: Option<CreateCheckoutSessionPaymentMethodOptionsGrabpay>contains details about the Grabpay payment method options.
ideal: Option<CreateCheckoutSessionPaymentMethodOptionsIdeal>contains details about the Ideal payment method options.
kakao_pay: Option<CreateCheckoutSessionPaymentMethodOptionsKakaoPay>contains details about the Kakao Pay payment method options.
klarna: Option<CreateCheckoutSessionPaymentMethodOptionsKlarna>contains details about the Klarna payment method options.
konbini: Option<CreateCheckoutSessionPaymentMethodOptionsKonbini>contains details about the Konbini payment method options.
kr_card: Option<CreateCheckoutSessionPaymentMethodOptionsKrCard>contains details about the Korean card payment method options.
link: Option<CreateCheckoutSessionPaymentMethodOptionsLink>contains details about the Link payment method options (Link is also known as Onelink in the UK).
mobilepay: Option<CreateCheckoutSessionPaymentMethodOptionsMobilepay>contains details about the Mobilepay payment method options.
multibanco: Option<CreateCheckoutSessionPaymentMethodOptionsMultibanco>contains details about the Multibanco payment method options.
contains details about the Naver Pay payment method options.
oxxo: Option<CreateCheckoutSessionPaymentMethodOptionsOxxo>contains details about the OXXO payment method options.
p24: Option<CreateCheckoutSessionPaymentMethodOptionsP24>contains details about the P24 payment method options.
pay_by_bank: Option<Value>contains details about the Pay By Bank payment method options.
payco: Option<CreateCheckoutSessionPaymentMethodOptionsPayco>contains details about the PAYCO payment method options.
paynow: Option<CreateCheckoutSessionPaymentMethodOptionsPaynow>contains details about the PayNow payment method options.
paypal: Option<CreateCheckoutSessionPaymentMethodOptionsPaypal>contains details about the PayPal payment method options.
payto: Option<CreateCheckoutSessionPaymentMethodOptionsPayto>contains details about the PayTo payment method options.
pix: Option<CreateCheckoutSessionPaymentMethodOptionsPix>contains details about the Pix payment method options.
revolut_pay: Option<CreateCheckoutSessionPaymentMethodOptionsRevolutPay>contains details about the RevolutPay payment method options.
samsung_pay: Option<CreateCheckoutSessionPaymentMethodOptionsSamsungPay>contains details about the Samsung Pay payment method options.
satispay: Option<CreateCheckoutSessionPaymentMethodOptionsSatispay>contains details about the Satispay payment method options.
scalapay: Option<CreateCheckoutSessionPaymentMethodOptionsScalapay>contains details about the Scalapay payment method options.
sepa_debit: Option<CreateCheckoutSessionPaymentMethodOptionsSepaDebit>contains details about the Sepa Debit payment method options.
sofort: Option<CreateCheckoutSessionPaymentMethodOptionsSofort>contains details about the Sofort payment method options.
sunbit: Option<CreateCheckoutSessionPaymentMethodOptionsSunbit>contains details about the Sunbit payment method options.
swish: Option<CreateCheckoutSessionPaymentMethodOptionsSwish>contains details about the Swish payment method options.
twint: Option<CreateCheckoutSessionPaymentMethodOptionsTwint>contains details about the TWINT payment method options.
upi: Option<CreateCheckoutSessionPaymentMethodOptionsUpi>contains details about the UPI payment method options.
us_bank_account: Option<CreateCheckoutSessionPaymentMethodOptionsUsBankAccount>contains details about the Us Bank Account payment method options.
wechat_pay: Option<CreateCheckoutSessionPaymentMethodOptionsWechatPay>contains details about the WeChat Pay payment method options.
Implementations