pub struct CreateCheckoutSessionPaymentMethodOptionsAcssDebit {
pub currency: Option<CreateCheckoutSessionPaymentMethodOptionsAcssDebitCurrency>,
pub mandate_options: Option<CreateCheckoutSessionPaymentMethodOptionsAcssDebitMandateOptions>,
pub setup_future_usage: Option<CreateCheckoutSessionPaymentMethodOptionsAcssDebitSetupFutureUsage>,
pub target_date: Option<String>,
pub verification_method: Option<CreateCheckoutSessionPaymentMethodOptionsAcssDebitVerificationMethod>,
}Expand description
contains details about the ACSS Debit payment method options.
You can’t set this parameter if ui_mode is elements.
Fields
currency: Option<CreateCheckoutSessionPaymentMethodOptionsAcssDebitCurrency>Three-letter ISO currency code, in lowercase.
Must be a supported currency.
This is only accepted for Checkout Sessions in setup mode.
mandate_options: Option<CreateCheckoutSessionPaymentMethodOptionsAcssDebitMandateOptions>Additional fields for Mandate creation
setup_future_usage: Option<CreateCheckoutSessionPaymentMethodOptionsAcssDebitSetupFutureUsage>Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn’t a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
target_date: Option<String>Controls when Stripe will attempt to debit the funds from the customer’s account. The date must be a string in YYYY-MM-DD format. The date must be in the future and between 3 and 15 calendar days from now.
verification_method: Option<CreateCheckoutSessionPaymentMethodOptionsAcssDebitVerificationMethod>Verification method for the intent
Implementations