pub struct CreateCheckoutSessionPaymentMethodOptionsCardInstallments {
pub enabled: Option<bool>,
}Expand description
Installment options for card payments
Fields
enabled: Option<bool>Setting to true enables installments for this Checkout Session. Setting to false will prevent any installment plan from applying to a payment.
Implementations