pub struct CreateCheckoutSessionPaymentMethodOptionsCustomerBalanceBankTransfer {
pub eu_bank_transfer: Option<CreateCheckoutSessionPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer>,
pub requested_address_types: Option<Vec<CreateCheckoutSessionPaymentMethodOptionsCustomerBalanceBankTransferRequestedAddressTypes>>,
pub type_: CreateCheckoutSessionPaymentMethodOptionsCustomerBalanceBankTransferType,
}Expand description
Configuration for the bank transfer funding type, if the funding_type is set to bank_transfer.
Fields
eu_bank_transfer: Option<CreateCheckoutSessionPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer>Configuration for eu_bank_transfer funding type.
requested_address_types: Option<Vec<CreateCheckoutSessionPaymentMethodOptionsCustomerBalanceBankTransferRequestedAddressTypes>>List of address types that should be returned in the financial_addresses response. If not specified, all valid types will be returned.
Permitted values include: sort_code, zengin, iban, or spei.
type_: CreateCheckoutSessionPaymentMethodOptionsCustomerBalanceBankTransferTypeThe list of bank transfer types that this PaymentIntent is allowed to use for funding.
Implementations