pub struct CreateCheckoutSessionPaymentMethodOptionsKlarnaSubscriptions {
pub interval: CreateCheckoutSessionPaymentMethodOptionsKlarnaSubscriptionsInterval,
pub interval_count: Option<u64>,
pub name: Option<String>,
pub next_billing: CreateCheckoutSessionPaymentMethodOptionsKlarnaSubscriptionsNextBilling,
pub reference: String,
}Expand description
Subscription details if the Checkout Session sets up a future subscription.
Fields
interval: CreateCheckoutSessionPaymentMethodOptionsKlarnaSubscriptionsIntervalUnit of time between subscription charges.
interval_count: Option<u64>The number of intervals (specified in the interval attribute) between subscription charges.
For example, interval=month and interval_count=3 charges every 3 months.
name: Option<String>Name for subscription.
next_billing: CreateCheckoutSessionPaymentMethodOptionsKlarnaSubscriptionsNextBillingDescribes the upcoming charge for this subscription.
reference: StringA non-customer-facing reference to correlate subscription charges in the Klarna app. Use a value that persists across subscription charges.
Implementations
Sourceimpl CreateCheckoutSessionPaymentMethodOptionsKlarnaSubscriptions
impl CreateCheckoutSessionPaymentMethodOptionsKlarnaSubscriptions
pub fn new( interval: impl Into<CreateCheckoutSessionPaymentMethodOptionsKlarnaSubscriptionsInterval>, next_billing: impl Into<CreateCheckoutSessionPaymentMethodOptionsKlarnaSubscriptionsNextBilling>, reference: impl Into<String>, ) -> Self