CreateCheckoutSessionPhoneNumberCollection

Struct CreateCheckoutSessionPhoneNumberCollection 

pub struct CreateCheckoutSessionPhoneNumberCollection {
    pub enabled: bool,
}
Controls phone number collection settings for the session.

We recommend that you review your privacy policy and check with your legal contacts before using this feature. Learn more about collecting phone numbers with Checkout.

Fields

enabled: bool

Set to true to enable phone number collection.

Can only be set in payment and subscription mode.

Implementations