pub struct CreateCheckoutSessionShippingAddressCollection {
pub allowed_countries: Vec<CreateCheckoutSessionShippingAddressCollectionAllowedCountries>,
}Expand description
When set, provides configuration for Checkout to collect a shipping address from a customer.
Fields
allowed_countries: Vec<CreateCheckoutSessionShippingAddressCollectionAllowedCountries>An array of two-letter ISO country codes representing which countries Checkout should provide as options for. shipping locations.
Implementations
Sourceimpl CreateCheckoutSessionShippingAddressCollection
impl CreateCheckoutSessionShippingAddressCollection
pub fn new( allowed_countries: impl Into<Vec<CreateCheckoutSessionShippingAddressCollectionAllowedCountries>>, ) -> Self