pub struct CreateCheckoutSessionShippingOptions {
pub shipping_rate: Option<String>,
pub shipping_rate_data: Option<CreateCheckoutSessionShippingOptionsShippingRateData>,
}Expand description
The shipping rate options to apply to this Session. Up to a maximum of 5.
Fields
shipping_rate: Option<String>The ID of the Shipping Rate to use for this shipping option.
shipping_rate_data: Option<CreateCheckoutSessionShippingOptionsShippingRateData>Parameters to be passed to Shipping Rate creation for this shipping option.
Implementations