pub struct CreateCheckoutSessionShippingOptionsShippingRateDataFixedAmountCurrencyOptions {
pub amount: i64,
pub tax_behavior: Option<CreateCheckoutSessionShippingOptionsShippingRateDataFixedAmountCurrencyOptionsTaxBehavior>,
}Expand description
Shipping rates defined in each available currency option. Each key must be a three-letter ISO currency code and a supported currency.
Fields
amount: i64A non-negative integer in cents representing how much to charge.
tax_behavior: Option<CreateCheckoutSessionShippingOptionsShippingRateDataFixedAmountCurrencyOptionsTaxBehavior>Specifies whether the rate is considered inclusive of taxes or exclusive of taxes.
One of inclusive, exclusive, or unspecified.
Implementations