pub struct CreateCheckoutSessionSubscriptionDataBillingCycleAnchorConfig {
pub day_of_month: i64,
pub hour: Option<i64>,
pub minute: Option<i64>,
pub month: Option<i64>,
pub second: Option<i64>,
}Expand description
Configures when the subscription schedule’s billing cycle anchors to a specific day of the week or month.
Fields
day_of_month: i64The day of the month the anchor should be. Ranges from 1 to 31.
hour: Option<i64>The hour of the day the anchor should be. Ranges from 0 to 23.
minute: Option<i64>The minute of the hour the anchor should be. Ranges from 0 to 59.
month: Option<i64>The month to start full cycle periods. Ranges from 1 to 12.
second: Option<i64>The second of the minute the anchor should be. Ranges from 0 to 59.
Implementations