pub struct CreateCheckoutSessionSubscriptionDataInvoiceSettings {
pub issuer: Option<CreateCheckoutSessionSubscriptionDataInvoiceSettingsIssuer>,
}Expand description
All invoices will be billed using the specified settings.
Fields
issuer: Option<CreateCheckoutSessionSubscriptionDataInvoiceSettingsIssuer>The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.
Implementations