pub struct CreateCheckoutSessionSubscriptionDataPendingInvoiceItemInterval {
pub interval: CreateCheckoutSessionSubscriptionDataPendingInvoiceItemIntervalInterval,
pub interval_count: Option<u64>,
}Expand description
Specifies an interval for how often to bill for any pending invoice items. It is analogous to calling Create an invoice for the given subscription at the specified interval.
Fields
interval: CreateCheckoutSessionSubscriptionDataPendingInvoiceItemIntervalIntervalSpecifies invoicing frequency. Either day, week, month or year.
interval_count: Option<u64>The number of intervals between invoices.
For example, interval=month and interval_count=3 bills every 3 months.
Maximum of one year interval allowed (1 year, 12 months, or 52 weeks).
Implementations
Sourceimpl CreateCheckoutSessionSubscriptionDataPendingInvoiceItemInterval
impl CreateCheckoutSessionSubscriptionDataPendingInvoiceItemInterval
pub fn new( interval: impl Into<CreateCheckoutSessionSubscriptionDataPendingInvoiceItemIntervalInterval>, ) -> Self