pub struct CreateCheckoutSessionWalletOptionsLink {
pub display: Option<CreateCheckoutSessionWalletOptionsLinkDisplay>,
}Expand description
contains details about the Link wallet options (Link is also known as Onelink in the UK).
Fields
display: Option<CreateCheckoutSessionWalletOptionsLinkDisplay>Specifies whether Checkout should display Link as a payment option.
By default, Checkout will display all the supported wallets that the Checkout Session was created with.
This is the auto behavior, and it is the default choice.
Implementations