pub struct CreateCheckoutSessionPaymentIntentDataTransferData {
pub amount: Option<i64>,
pub destination: String,
}Expand description
The parameters used to automatically create a Transfer when the payment succeeds. For more information, see the PaymentIntents use case for connected accounts.
Fields
amount: Option<i64>The amount that will be transferred automatically when a charge succeeds.
destination: StringIf specified, successful charges will be attributed to the destination
account for tax reporting, and the funds from charges will be transferred
to the destination account. The ID of the resulting transfer will be
returned on the successful charge’s transfer field.
Implementations