pub struct CreateCheckoutSessionPhoneNumberCollection {
pub enabled: bool,
}Expand description
Controls phone number collection settings for the session.
We recommend that you review your privacy policy and check with your legal contacts before using this feature. Learn more about collecting phone numbers with Checkout.
Fields
enabled: boolSet to true to enable phone number collection.
Can only be set in payment and subscription mode.
Implementations