pub struct UpdateCheckoutSessionLineItems {
pub adjustable_quantity: Option<UpdateCheckoutSessionLineItemsAdjustableQuantity>,
pub id: Option<String>,
pub metadata: Option<HashMap<String, String>>,
pub price: Option<String>,
pub price_data: Option<UpdateCheckoutSessionLineItemsPriceData>,
pub quantity: Option<u64>,
pub tax_rates: Option<Vec<String>>,
}Expand description
A list of items the customer is purchasing.
When updating line items, you must retransmit the entire array of line items.
To retain an existing line item, specify its id.
To update an existing line item, specify its id along with the new values of the fields to update.
To add a new line item, specify one of price or price_data and quantity.
To remove an existing line item, omit the line item’s ID from the retransmitted array.
To reorder a line item, specify it at the desired position in the retransmitted array.
Fields
adjustable_quantity: Option<UpdateCheckoutSessionLineItemsAdjustableQuantity>When set, provides configuration for this item’s quantity to be adjusted by the customer during Checkout.
id: Option<String>ID of an existing line item.
metadata: Option<HashMap<String, String>>Set of key-value pairs that you can attach to an object.
This can be useful for storing additional information about the object in a structured format.
Individual keys can be unset by posting an empty value to them.
All keys can be unset by posting an empty value to metadata.
price: Option<String>The ID of the Price.
One of price or price_data is required when creating a new line item.
price_data: Option<UpdateCheckoutSessionLineItemsPriceData>Data used to generate a new Price object inline.
One of price or price_data is required when creating a new line item.
quantity: Option<u64>The quantity of the line item being purchased.
Quantity should not be defined when recurring.usage_type=metered.
tax_rates: Option<Vec<String>>The tax rates which apply to this line item.
Implementations